@@ -128,7 +128,7 @@ int main()
     cameraSensor->ConnectImageCallback(&OnImageFrame);
 
   // Force the camera to generate an image
-  mgr.RunOnce(gz::common::Time::Zero, true);
+  mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
 
   return 0;
 }
