@@ -15,26 +15,26 @@
  *
 */
 
-#ifdef _WIN32
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#pragma warning(disable: 4251)
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/fluid_pressure.pb.h>
-#ifdef _WIN32
-#pragma warning(pop)
+#include <gz/msgs/fluid_pressure.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
 #endif
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/sensors/GaussianNoiseModel.hh"
-#include "ignition/sensors/Noise.hh"
-#include "ignition/sensors/SensorTypes.hh"
-#include "ignition/sensors/SensorFactory.hh"
-#include "ignition/sensors/AirPressureSensor.hh"
+#include "gz/sensors/GaussianNoiseModel.hh"
+#include "gz/sensors/Noise.hh"
+#include "gz/sensors/SensorTypes.hh"
+#include "gz/sensors/SensorFactory.hh"
+#include "gz/sensors/AirPressureSensor.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace sensors;
 
 // Constants. These constants from from RotorS:
@@ -51,7 +51,7 @@ static constexpr double kAirConstantDimensionless = kGravityMagnitude *
         (kGasConstantNmPerKmolKelvin * -kTempLapseKelvinPerMeter);
 
 /// \brief Private data for AirPressureSensor
-class ignition::sensors::AirPressureSensorPrivate
+class gz::sensors::AirPressureSensorPrivate
 {
   /// \brief node to create publisher
   public: transport::Node node;
@@ -113,7 +113,7 @@ bool AirPressureSensor::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/air_pressure");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<ignition::msgs::FluidPressure>(
+      this->dataPtr->node.Advertise<msgs::FluidPressure>(
       this->Topic());
 
   if (!this->dataPtr->pub)
@@ -193,7 +193,7 @@ bool AirPressureSensor::Update(
         NoiseType::GAUSSIAN)
     {
      GaussianNoiseModelPtr gaussian =
-       std::dynamic_pointer_cast<sensors::GaussianNoiseModel>(
+       std::dynamic_pointer_cast<GaussianNoiseModel>(
            this->dataPtr->noises[AIR_PRESSURE_NOISE_PASCALS]);
       msg.set_variance(sqrt(gaussian->StdDev()));
     }
