@@ -14,46 +14,46 @@
  * limitations under the License.
  *
 */
-#ifdef _WIN32
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#pragma warning(disable: 4251)
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/camera_info.pb.h>
-#ifdef _WIN32
-#pragma warning(pop)
+#include <gz/msgs/camera_info.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
 #endif
 
 #include <mutex>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Event.hh>
-#include <ignition/common/Image.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/common/StringUtils.hh>
-#include <ignition/math/Angle.hh>
-#include <ignition/math/Helpers.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Event.hh>
+#include <gz/common/Image.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/common/StringUtils.hh>
+#include <gz/math/Angle.hh>
+#include <gz/math/Helpers.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/sensors/CameraSensor.hh"
-#include "ignition/sensors/ImageBrownDistortionModel.hh"
-#include "ignition/sensors/ImageDistortion.hh"
-#include "ignition/sensors/ImageGaussianNoiseModel.hh"
-#include "ignition/sensors/ImageNoise.hh"
-#include "ignition/sensors/Manager.hh"
-#include "ignition/sensors/RenderingEvents.hh"
-#include "ignition/sensors/SensorFactory.hh"
-#include "ignition/sensors/SensorTypes.hh"
+#include "gz/sensors/CameraSensor.hh"
+#include "gz/sensors/ImageBrownDistortionModel.hh"
+#include "gz/sensors/ImageDistortion.hh"
+#include "gz/sensors/ImageGaussianNoiseModel.hh"
+#include "gz/sensors/ImageNoise.hh"
+#include "gz/sensors/Manager.hh"
+#include "gz/sensors/RenderingEvents.hh"
+#include "gz/sensors/SensorFactory.hh"
+#include "gz/sensors/SensorTypes.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace sensors;
 
 /// \brief Private data for CameraSensor
-class ignition::sensors::CameraSensorPrivate
+class gz::sensors::CameraSensorPrivate
 {
   /// \brief Callback for triggered subscription
   /// \param[in] _msg Boolean message
-  public: void OnTrigger(const ignition::msgs::Boolean &_msg);
+  public: void OnTrigger(const msgs::Boolean &_msg);
 
   /// \brief Save an image
   /// \param[in] _data the image data to be saved
@@ -65,7 +65,7 @@ class ignition::sensors::CameraSensorPrivate
   /// of the path was not possible.
   /// \sa ImageSaver
   public: bool SaveImage(const unsigned char *_data, unsigned int _width,
-    unsigned int _height, ignition::common::Image::PixelFormatType _format);
+    unsigned int _height, common::Image::PixelFormatType _format);
 
   /// \brief node to create publisher
   public: transport::Node node;
@@ -80,10 +80,10 @@ class ignition::sensors::CameraSensorPrivate
   public: bool initialized = false;
 
   /// \brief Rendering camera
-  public: ignition::rendering::CameraPtr camera;
+  public: rendering::CameraPtr camera;
 
   /// \brief Pointer to an image to be published
-  public: ignition::rendering::Image image;
+  public: rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
@@ -93,11 +93,11 @@ class ignition::sensors::CameraSensorPrivate
 
   /// \brief Event that is used to trigger callbacks when a new image
   /// is generated
-  public: ignition::common::EventT<
-          void(const ignition::msgs::Image &)> imageEvent;
+  public: common::EventT<
+          void(const msgs::Image &)> imageEvent;
 
   /// \brief Connection to the Manager's scene change event.
-  public: ignition::common::ConnectionPtr sceneChangeConnection;
+  public: common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -129,6 +129,9 @@ class ignition::sensors::CameraSensorPrivate
   /// \brief Camera information message.
   public: msgs::CameraInfo infoMsg;
 
+  /// \brief The frame this camera uses in its camera_info topic.
+  public: std::string opticalFrameId{""};
+
   /// \brief Topic for info message.
   public: std::string infoTopic{""};
 
@@ -212,10 +215,13 @@ bool CameraSensor::CreateCamera()
   switch (pixelFormat)
   {
     case sdf::PixelFormatType::RGB_INT8:
-      this->dataPtr->camera->SetImageFormat(ignition::rendering::PF_R8G8B8);
+      this->dataPtr->camera->SetImageFormat(rendering::PF_R8G8B8);
       break;
     case sdf::PixelFormatType::L_INT8:
-      this->dataPtr->camera->SetImageFormat(ignition::rendering::PF_L8);
+      this->dataPtr->camera->SetImageFormat(rendering::PF_L8);
+      break;
+    case sdf::PixelFormatType::L_INT16:
+      this->dataPtr->camera->SetImageFormat(rendering::PF_L16);
       break;
     default:
       ignerr << "Unsupported pixel format ["
@@ -284,8 +290,13 @@ bool CameraSensor::Load(const sdf::Sensor &_sdf)
   if (this->Topic().empty())
     this->SetTopic("/camera");
 
+  if (!_sdf.CameraSensor()->CameraInfoTopic().empty())
+  {
+    this->dataPtr->infoTopic = _sdf.CameraSensor()->CameraInfoTopic();
+  }
+
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<ignition::msgs::Image>(
+      this->dataPtr->node.Advertise<msgs::Image>(
           this->Topic());
   if (!this->dataPtr->pub)
   {
@@ -346,14 +357,14 @@ bool CameraSensor::Load(sdf::ElementPtr _sdf)
 }
 
 /////////////////////////////////////////////////
-ignition::common::ConnectionPtr CameraSensor::ConnectImageCallback(
-    std::function<void(const ignition::msgs::Image &)> _callback)
+common::ConnectionPtr CameraSensor::ConnectImageCallback(
+    std::function<void(const msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void CameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
+void CameraSensor::SetScene(rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -388,6 +399,12 @@ bool CameraSensor::Update(const std::chrono::steady_clock::duration &_now)
   // move the camera to the current pose
   this->dataPtr->camera->SetLocalPose(this->Pose());
 
+  if (this->HasInfoConnections())
+  {
+    // publish the camera info message
+    this->PublishInfo(_now);
+  }
+
   // render only if necessary
   if (this->dataPtr->isTriggeredCamera &&
       !this->dataPtr->isTriggered)
@@ -402,7 +419,7 @@ bool CameraSensor::Update(const std::chrono::steady_clock::duration &_now)
     if (this->dataPtr->generatingData)
     {
       igndbg << "Disabling camera sensor: '" << this->Name() << "' data "
-             << "generation. " << std::endl;;
+             << "generation. " << std::endl;
       this->dataPtr->generatingData = false;
     }
 
@@ -413,86 +430,90 @@ bool CameraSensor::Update(const std::chrono::steady_clock::duration &_now)
     if (!this->dataPtr->generatingData)
     {
       igndbg << "Enabling camera sensor: '" << this->Name() << "' data "
-             << "generation." << std::endl;;
+             << "generation." << std::endl;
       this->dataPtr->generatingData = true;
     }
   }
 
-  // generate sensor data
-  this->Render();
+  if (this->HasImageConnections() || this->dataPtr->saveImage)
   {
-    IGN_PROFILE("CameraSensor::Update Copy image");
-    this->dataPtr->camera->Copy(this->dataPtr->image);
-  }
-
-  unsigned int width = this->dataPtr->camera->ImageWidth();
-  unsigned int height = this->dataPtr->camera->ImageHeight();
-  unsigned char *data = this->dataPtr->image.Data<unsigned char>();
-
-  ignition::common::Image::PixelFormatType
-      format{common::Image::UNKNOWN_PIXEL_FORMAT};
-  msgs::PixelFormatType msgsPixelFormat =
-    msgs::PixelFormatType::UNKNOWN_PIXEL_FORMAT;
-
-  switch (this->dataPtr->camera->ImageFormat())
-  {
-    case ignition::rendering::PF_R8G8B8:
-      format = ignition::common::Image::RGB_INT8;
-      msgsPixelFormat = msgs::PixelFormatType::RGB_INT8;
-      break;
-    case ignition::rendering::PF_L8:
-      format = ignition::common::Image::L_INT8;
-      msgsPixelFormat = msgs::PixelFormatType::L_INT8;
-      break;
-    default:
-      ignerr << "Unsupported pixel format ["
-        << this->dataPtr->camera->ImageFormat() << "]\n";
-      break;
-  }
-
-  // create message
-  ignition::msgs::Image msg;
-  {
-    IGN_PROFILE("CameraSensor::Update Message");
-    msg.set_width(width);
-    msg.set_height(height);
-    msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
-                 this->dataPtr->camera->ImageFormat()));
-    msg.set_pixel_format_type(msgsPixelFormat);
-    *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
-    auto frame = msg.mutable_header()->add_data();
-    frame->set_key("frame_id");
-    frame->add_value(this->FrameId());
-    msg.set_data(data, this->dataPtr->camera->ImageMemorySize());
-  }
-
-  // publish the image message
-  {
-    this->AddSequence(msg.mutable_header());
-    IGN_PROFILE("CameraSensor::Update Publish");
-    this->dataPtr->pub.Publish(msg);
-
-    // publish the camera info message
-    this->PublishInfo(_now);
-  }
-
-  // Trigger callbacks.
-  if (this->dataPtr->imageEvent.ConnectionCount() > 0)
-  {
-    try
+    // generate sensor data
+    this->Render();
     {
-      this->dataPtr->imageEvent(msg);
+      IGN_PROFILE("CameraSensor::Update Copy image");
+      this->dataPtr->camera->Copy(this->dataPtr->image);
     }
-    catch(...)
-    {
-      ignerr << "Exception thrown in an image callback.\n";
-    }
-  }
 
-  // Save image
-  if (this->dataPtr->saveImage)
-  {
-    this->dataPtr->SaveImage(data, width, height, format);
+    unsigned int width = this->dataPtr->camera->ImageWidth();
+    unsigned int height = this->dataPtr->camera->ImageHeight();
+    unsigned char *data = this->dataPtr->image.Data<unsigned char>();
+
+    common::Image::PixelFormatType
+        format{common::Image::UNKNOWN_PIXEL_FORMAT};
+    msgs::PixelFormatType msgsPixelFormat =
+      msgs::PixelFormatType::UNKNOWN_PIXEL_FORMAT;
+
+    switch (this->dataPtr->camera->ImageFormat())
+    {
+      case rendering::PF_R8G8B8:
+        format = common::Image::RGB_INT8;
+        msgsPixelFormat = msgs::PixelFormatType::RGB_INT8;
+        break;
+      case rendering::PF_L8:
+        format = common::Image::L_INT8;
+        msgsPixelFormat = msgs::PixelFormatType::L_INT8;
+        break;
+      case rendering::PF_L16:
+        format = common::Image::L_INT16;
+        msgsPixelFormat = msgs::PixelFormatType::L_INT16;
+        break;
+      default:
+        ignerr << "Unsupported pixel format ["
+          << this->dataPtr->camera->ImageFormat() << "]\n";
+        break;
+    }
+
+    // create message
+    msgs::Image msg;
+    {
+      IGN_PROFILE("CameraSensor::Update Message");
+      msg.set_width(width);
+      msg.set_height(height);
+      msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
+                   this->dataPtr->camera->ImageFormat()));
+      msg.set_pixel_format_type(msgsPixelFormat);
+      *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
+      auto frame = msg.mutable_header()->add_data();
+      frame->set_key("frame_id");
+      frame->add_value(this->dataPtr->opticalFrameId);
+      msg.set_data(data, this->dataPtr->camera->ImageMemorySize());
+    }
+
+    // publish the image message
+    {
+      this->AddSequence(msg.mutable_header());
+      IGN_PROFILE("CameraSensor::Update Publish");
+      this->dataPtr->pub.Publish(msg);
+    }
+
+    // Trigger callbacks.
+    if (this->dataPtr->imageEvent.ConnectionCount() > 0)
+    {
+      try
+      {
+        this->dataPtr->imageEvent(msg);
+      }
+      catch(...)
+      {
+        ignerr << "Exception thrown in an image callback.\n";
+      }
+    }
+
+    // Save image
+    if (this->dataPtr->saveImage)
+    {
+      this->dataPtr->SaveImage(data, width, height, format);
+    }
   }
 
   if (this->dataPtr->isTriggeredCamera)
@@ -504,7 +525,7 @@ bool CameraSensor::Update(const std::chrono::steady_clock::duration &_now)
 }
 
 //////////////////////////////////////////////////
-void CameraSensorPrivate::OnTrigger(const ignition::msgs::Boolean &/*_msg*/)
+void CameraSensorPrivate::OnTrigger(const msgs::Boolean &/*_msg*/)
 {
   std::lock_guard<std::mutex> lock(this->mutex);
   this->isTriggered = true;
@@ -513,12 +534,12 @@ void CameraSensorPrivate::OnTrigger(const ignition::msgs::Boolean &/*_msg*/)
 //////////////////////////////////////////////////
 bool CameraSensorPrivate::SaveImage(const unsigned char *_data,
     unsigned int _width, unsigned int _height,
-    ignition::common::Image::PixelFormatType _format)
+    common::Image::PixelFormatType _format)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!ignition::common::isDirectory(this->saveImagePath))
+  if (!common::isDirectory(this->saveImagePath))
   {
-    if (!ignition::common::createDirectories(this->saveImagePath))
+    if (!common::createDirectories(this->saveImagePath))
       return false;
   }
 
@@ -526,11 +547,11 @@ bool CameraSensorPrivate::SaveImage(const unsigned char *_data,
                          std::to_string(this->saveImageCounter) + ".png";
   ++this->saveImageCounter;
 
-  ignition::common::Image localImage;
+  common::Image localImage;
   localImage.SetFromData(_data, _width, _height, _format);
 
   localImage.SavePNG(
-      ignition::common::joinPaths(this->saveImagePath, filename));
+      common::joinPaths(this->saveImagePath, filename));
   return true;
 }
 
@@ -565,17 +586,17 @@ std::string CameraSensor::InfoTopic() const
 //////////////////////////////////////////////////
 bool CameraSensor::AdvertiseInfo()
 {
-  // TODO(anyone) Make info topic configurable from SDF
-  // Info topic must be at same level as image topic
-  auto parts = common::Split(this->Topic(), '/');
-  parts.pop_back();
-
-  for (const auto &part : parts)
+  if (this->dataPtr->infoTopic.empty())
   {
-    if (!part.empty())
-      this->dataPtr->infoTopic += "/" + part;
+    auto parts = common::Split(this->Topic(), '/');
+    parts.pop_back();
+    for (const auto &part : parts)
+    {
+      if (!part.empty())
+        this->dataPtr->infoTopic += "/" + part;
+    }
+    this->dataPtr->infoTopic += "/camera_info";
   }
-  this->dataPtr->infoTopic += "/camera_info";
 
   return this->AdvertiseInfo(this->dataPtr->infoTopic);
 }
@@ -586,7 +607,7 @@ bool CameraSensor::AdvertiseInfo(const std::string &_topic)
   this->dataPtr->infoTopic = _topic;
 
   this->dataPtr->infoPub =
-      this->dataPtr->node.Advertise<ignition::msgs::CameraInfo>(
+      this->dataPtr->node.Advertise<msgs::CameraInfo>(
       this->dataPtr->infoTopic);
   if (!this->dataPtr->infoPub)
   {
@@ -642,19 +663,18 @@ void CameraSensor::PopulateInfo(const sdf::Camera *_cameraSdf)
   intrinsics->add_k(0.0);
   intrinsics->add_k(1.0);
 
-  // TODO(anyone) Get tx and ty from SDF
   msgs::CameraInfo::Projection *proj =
     this->dataPtr->infoMsg.mutable_projection();
 
-  proj->add_p(_cameraSdf->LensIntrinsicsFx());
+  proj->add_p(_cameraSdf->LensProjectionFx());
   proj->add_p(0.0);
-  proj->add_p(_cameraSdf->LensIntrinsicsCx());
-  proj->add_p(-_cameraSdf->LensIntrinsicsFx() * this->dataPtr->baseline);
+  proj->add_p(_cameraSdf->LensProjectionCx());
+  proj->add_p(_cameraSdf->LensProjectionTx());
 
   proj->add_p(0.0);
-  proj->add_p(_cameraSdf->LensIntrinsicsFy());
-  proj->add_p(_cameraSdf->LensIntrinsicsCy());
-  proj->add_p(0.0);
+  proj->add_p(_cameraSdf->LensProjectionFy());
+  proj->add_p(_cameraSdf->LensProjectionCy());
+  proj->add_p(_cameraSdf->LensProjectionTy());
 
   proj->add_p(0.0);
   proj->add_p(0.0);
@@ -676,11 +696,20 @@ void CameraSensor::PopulateInfo(const sdf::Camera *_cameraSdf)
 
   // Note: while Gazebo interprets the camera frame to be looking towards +X,
   // other tools, such as ROS, may interpret this frame as looking towards +Z.
-  // TODO(anyone) Expose the `frame_id` as an SDF parameter so downstream users
-  // can populate it with arbitrary frames.
+  // To make this configurable the user has the option to set an optical frame.
+  // If the user has set <optical_frame_id> in the cameraSdf use it,
+  // otherwise fall back to the sensor frame.
+  if (_cameraSdf->OpticalFrameId().empty())
+  {
+   this->dataPtr->opticalFrameId = this->FrameId();
+  }
+  else
+  {
+   this->dataPtr->opticalFrameId = _cameraSdf->OpticalFrameId();
+  }
   auto infoFrame = this->dataPtr->infoMsg.mutable_header()->add_data();
   infoFrame->set_key("frame_id");
-  infoFrame->add_value(this->FrameId());
+  infoFrame->add_value(this->dataPtr->opticalFrameId);
 
   this->dataPtr->infoMsg.set_width(width);
   this->dataPtr->infoMsg.set_height(height);
@@ -709,6 +738,18 @@ double CameraSensor::Baseline() const
 //////////////////////////////////////////////////
 bool CameraSensor::HasConnections() const
 {
+  return this->HasImageConnections() || this->HasInfoConnections();
+}
+
+//////////////////////////////////////////////////
+bool CameraSensor::HasImageConnections() const
+{
   return (this->dataPtr->pub && this->dataPtr->pub.HasConnections()) ||
-      this->dataPtr->imageEvent.ConnectionCount() > 0u;
+         this->dataPtr->imageEvent.ConnectionCount() > 0u;
+}
+
+//////////////////////////////////////////////////
+bool CameraSensor::HasInfoConnections() const
+{
+  return this->dataPtr->infoPub && this->dataPtr->infoPub.HasConnections();
 }
