@@ -14,34 +14,34 @@
  * limitations under the License.
  *
 */
-#ifdef _WIN32
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#pragma warning(disable: 4251)
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/pointcloud_packed.pb.h>
-#ifdef _WIN32
-#pragma warning(pop)
+#include <gz/msgs/pointcloud_packed.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
 #endif
 
 #include <mutex>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Image.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/common/SystemPaths.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Image.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/common/SystemPaths.hh>
 
-#include <ignition/math/Angle.hh>
-#include <ignition/math/Helpers.hh>
+#include <gz/math/Angle.hh>
+#include <gz/math/Helpers.hh>
 
-#include <ignition/transport/Node.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/sensors/DepthCameraSensor.hh"
-#include "ignition/sensors/Manager.hh"
-#include "ignition/sensors/SensorFactory.hh"
-#include "ignition/sensors/ImageGaussianNoiseModel.hh"
-#include "ignition/sensors/ImageNoise.hh"
-#include "ignition/sensors/RenderingEvents.hh"
+#include "gz/sensors/DepthCameraSensor.hh"
+#include "gz/sensors/Manager.hh"
+#include "gz/sensors/SensorFactory.hh"
+#include "gz/sensors/ImageGaussianNoiseModel.hh"
+#include "gz/sensors/ImageNoise.hh"
+#include "gz/sensors/RenderingEvents.hh"
 
 #include "PointCloudUtil.hh"
 
@@ -52,7 +52,7 @@
 #endif
 
 /// \brief Private data for DepthCameraSensor
-class ignition::sensors::DepthCameraSensorPrivate
+class gz::sensors::DepthCameraSensorPrivate
 {
   /// \brief Save an image
   /// \param[in] _data the image data to be saved
@@ -64,7 +64,7 @@ class ignition::sensors::DepthCameraSensorPrivate
   /// of the path was not possible.
   /// \sa ImageSaver
   public: bool SaveImage(const float *_data, unsigned int _width,
-    unsigned int _height, ignition::common::Image::PixelFormatType _format);
+    unsigned int _height, gz::common::Image::PixelFormatType _format);
 
   /// \brief Helper function to convert depth data to depth image
   /// \param[in] _data depth data
@@ -84,7 +84,7 @@ class ignition::sensors::DepthCameraSensorPrivate
   public: bool initialized = false;
 
     /// \brief Rendering camera
-  public: ignition::rendering::DepthCameraPtr depthCamera;
+  public: gz::rendering::DepthCameraPtr depthCamera;
 
   /// \brief Depth data buffer.
   public: float *depthBuffer = nullptr;
@@ -99,24 +99,24 @@ class ignition::sensors::DepthCameraSensorPrivate
   public: float near = 0.0;
 
   /// \brief Pointer to an image to be published
-  public: ignition::rendering::Image image;
+  public: gz::rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
 
   /// \brief Event that is used to trigger callbacks when a new image
   /// is generated
-  public: ignition::common::EventT<
-          void(const ignition::msgs::Image &)> imageEvent;
+  public: gz::common::EventT<
+          void(const gz::msgs::Image &)> imageEvent;
 
   /// \brief Connection from depth camera with new depth data
-  public: ignition::common::ConnectionPtr depthConnection;
+  public: gz::common::ConnectionPtr depthConnection;
 
   /// \brief Connection from depth camera with new point cloud data
-  public: ignition::common::ConnectionPtr pointCloudConnection;
+  public: gz::common::ConnectionPtr pointCloudConnection;
 
   /// \brief Connection to the Manager's scene change event.
-  public: ignition::common::ConnectionPtr sceneChangeConnection;
+  public: gz::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -147,7 +147,7 @@ class ignition::sensors::DepthCameraSensorPrivate
   public: transport::Node::Publisher pointPub;
 };
 
-using namespace ignition;
+using namespace gz;
 using namespace sensors;
 
 //////////////////////////////////////////////////
@@ -178,19 +178,19 @@ bool DepthCameraSensorPrivate::ConvertDepthToImage(
 //////////////////////////////////////////////////
 bool DepthCameraSensorPrivate::SaveImage(const float *_data,
     unsigned int _width, unsigned int _height,
-    ignition::common::Image::PixelFormatType /*_format*/)
+    common::Image::PixelFormatType /*_format*/)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!ignition::common::isDirectory(this->saveImagePath))
+  if (!common::isDirectory(this->saveImagePath))
   {
-    if (!ignition::common::createDirectories(this->saveImagePath))
+    if (!common::createDirectories(this->saveImagePath))
       return false;
   }
 
   if (_width == 0 || _height == 0)
     return false;
 
-  ignition::common::Image localImage;
+  common::Image localImage;
 
   unsigned int depthSamples = _width * _height;
   unsigned int depthBufferSize = depthSamples * 3;
@@ -206,7 +206,7 @@ bool DepthCameraSensorPrivate::SaveImage(const float *_data,
   localImage.SetFromData(imgDepthBuffer, _width, _height,
       common::Image::RGB_INT8);
   localImage.SavePNG(
-      ignition::common::joinPaths(this->saveImagePath, filename));
+      common::joinPaths(this->saveImagePath, filename));
 
   delete[] imgDepthBuffer;
   return true;
@@ -275,7 +275,7 @@ bool DepthCameraSensor::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/camera/depth");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<ignition::msgs::Image>(
+      this->dataPtr->node.Advertise<msgs::Image>(
           this->Topic());
   if (!this->dataPtr->pub)
   {
@@ -292,7 +292,7 @@ bool DepthCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the point cloud publisher
   this->dataPtr->pointPub =
-      this->dataPtr->node.Advertise<ignition::msgs::PointCloudPacked>(
+      this->dataPtr->node.Advertise<msgs::PointCloudPacked>(
           this->Topic() + "/points");
   if (!this->dataPtr->pointPub)
   {
@@ -447,8 +447,8 @@ void DepthCameraSensor::OnNewDepthFrame(const float *_scan,
   unsigned int depthSamples = _width * _height;
   unsigned int depthBufferSize = depthSamples * sizeof(float);
 
-  ignition::common::Image::PixelFormatType format =
-    ignition::common::Image::ConvertPixelFormat(_format);
+  common::Image::PixelFormatType format =
+    common::Image::ConvertPixelFormat(_format);
 
   if (!this->dataPtr->depthBuffer)
     this->dataPtr->depthBuffer = new float[depthSamples];
@@ -482,20 +482,20 @@ void DepthCameraSensor::OnNewRgbPointCloud(const float *_scan,
 }
 
 /////////////////////////////////////////////////
-ignition::rendering::DepthCameraPtr DepthCameraSensor::DepthCamera()
+rendering::DepthCameraPtr DepthCameraSensor::DepthCamera()
 {
   return this->dataPtr->depthCamera;
 }
 
 /////////////////////////////////////////////////
-ignition::common::ConnectionPtr DepthCameraSensor::ConnectImageCallback(
-    std::function<void(const ignition::msgs::Image &)> _callback)
+common::ConnectionPtr DepthCameraSensor::ConnectImageCallback(
+    std::function<void(const msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void DepthCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
+void DepthCameraSensor::SetScene(rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -527,6 +527,17 @@ bool DepthCameraSensor::Update(
     return false;
   }
 
+  if (this->HasInfoConnections())
+  {
+    // publish the camera info message
+    this->PublishInfo(_now);
+  }
+
+  if (!this->HasDepthConnections() && !this->HasPointConnections())
+  {
+    return false;
+  }
+
   // generate sensor data
   this->Render();
 
@@ -536,7 +547,7 @@ bool DepthCameraSensor::Update(
   auto msgsFormat = msgs::PixelFormatType::R_FLOAT32;
 
   // create message
-  ignition::msgs::Image msg;
+  msgs::Image msg;
   msg.set_width(width);
   msg.set_height(height);
   msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
@@ -555,8 +566,6 @@ bool DepthCameraSensor::Update(
   this->AddSequence(msg.mutable_header(), "default");
   this->dataPtr->pub.Publish(msg);
 
-  // publish the camera info message
-  this->PublishInfo(_now);
 
   if (this->dataPtr->imageEvent.ConnectionCount() > 0u)
   {
@@ -571,7 +580,7 @@ bool DepthCameraSensor::Update(
     }
   }
 
-  if (this->dataPtr->pointPub.HasConnections() &&
+  if (this->HasPointConnections() &&
       this->dataPtr->pointCloudBuffer)
   {
     // Set the time stamp
@@ -637,7 +646,19 @@ double DepthCameraSensor::NearClip() const
 //////////////////////////////////////////////////
 bool DepthCameraSensor::HasConnections() const
 {
-  return (this->dataPtr->pub && this->dataPtr->pub.HasConnections()) ||
-      (this->dataPtr->pointPub && this->dataPtr->pointPub.HasConnections()) ||
-      this->dataPtr->imageEvent.ConnectionCount() > 0u;
+  return this->HasDepthConnections() || this->HasPointConnections() ||
+      this->HasInfoConnections();
+}
+
+//////////////////////////////////////////////////
+bool DepthCameraSensor::HasDepthConnections() const
+{
+  return (this->dataPtr->pub && this->dataPtr->pub.HasConnections())
+         || this->dataPtr->imageEvent.ConnectionCount() > 0u;
+}
+
+//////////////////////////////////////////////////
+bool DepthCameraSensor::HasPointConnections() const
+{
+  return this->dataPtr->pointPub && this->dataPtr->pointPub.HasConnections();
 }
