@@ -15,21 +15,21 @@
  *
 */
 
-#include "ignition/sensors/Sensor.hh"
+#include "gz/sensors/Sensor.hh"
 
 #include <chrono>
 #include <map>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/msgs/double.pb.h>
-#include <ignition/transport/Node.hh>
-#include <ignition/transport/TopicUtils.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/msgs/double.pb.h>
+#include <gz/transport/Node.hh>
+#include <gz/transport/TopicUtils.hh>
 
-using namespace ignition::sensors;
+using namespace gz::sensors;
 
-class ignition::sensors::SensorPrivate
+class gz::sensors::SensorPrivate
 {
   /// \brief Populates fields from a <sensor> DOM
   public: bool PopulateFromSDF(const sdf::Sensor &_sdf);
@@ -49,7 +49,7 @@ class ignition::sensors::SensorPrivate
   /// <update_rate> value from SDF, and zero is allowed only when zero is also
   /// in SDF.
   /// \return True if a valid topic was set.
-  public: void SetRate(const ignition::msgs::Double &_rate);
+  public: void SetRate(const gz::msgs::Double &_rate);
 
   /// \brief id given to sensor when constructed
   public: SensorId id;
@@ -67,7 +67,7 @@ class ignition::sensors::SensorPrivate
   public: std::string topic;
 
   /// \brief Pose of the sensor
-  public: ignition::math::Pose3d pose;
+  public: gz::math::Pose3d pose;
 
   /// \brief Flag to enable publishing performance metrics.
   public: bool enableMetrics{false};
@@ -91,10 +91,10 @@ class ignition::sensors::SensorPrivate
   public: std::chrono::duration<double> lastUpdateTime{0};
 
   /// \brief Transport node.
-  public: ignition::transport::Node node;
+  public: gz::transport::Node node;
 
   /// \brief Publishes the PerformanceSensorMetrics message.
-  public: ignition::transport::Node::Publisher performanceSensorMetricsPub;
+  public: gz::transport::Node::Publisher performanceSensorMetricsPub;
 
   /// \brief SDF element with sensor information.
   public: sdf::ElementPtr sdf = nullptr;
@@ -305,7 +305,7 @@ void Sensor::PublishMetrics(const std::chrono::duration<double> &_now)
 //////////////////////////////////////////////////
 void SensorPrivate::PublishMetrics(const std::chrono::duration<double> &_now)
 {
-  if(!this->performanceSensorMetricsPub)
+  if (!this->performanceSensorMetricsPub)
   {
     const auto validTopic = transport::TopicUtils::AsValidTopic(
       this->topic + "/performance_metrics");
@@ -329,7 +329,7 @@ void SensorPrivate::PublishMetrics(const std::chrono::duration<double> &_now)
   double realUpdateRate;
   const auto clockNow = std::chrono::steady_clock::now();
   // If lastUpdateTime == 0 means it wasn't initialized yet.
-  if(this->lastUpdateTime.count() > 0)
+  if (this->lastUpdateTime.count() > 0)
   {
     const double diffSimUpdate = _now.count() -
       this->lastUpdateTime.count();
@@ -393,7 +393,7 @@ void SensorPrivate::SetRate(const ignition::msgs::Double &_rate)
 }
 
 //////////////////////////////////////////////////
-ignition::math::Pose3d Sensor::Pose() const
+gz::math::Pose3d Sensor::Pose() const
 {
   return this->dataPtr->pose;
 }
@@ -411,7 +411,7 @@ void Sensor::SetParent(const std::string &_parent)
 }
 
 //////////////////////////////////////////////////
-void Sensor::SetPose(const ignition::math::Pose3d &_pose)
+void Sensor::SetPose(const gz::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -481,7 +481,7 @@ std::chrono::steady_clock::duration Sensor::NextDataUpdateTime() const
 }
 
 /////////////////////////////////////////////////
-void Sensor::AddSequence(ignition::msgs::Header *_msg,
+void Sensor::AddSequence(gz::msgs::Header *_msg,
                          const std::string &_seqKey)
 {
   std::string value = "0";
@@ -505,7 +505,7 @@ void Sensor::AddSequence(ignition::msgs::Header *_msg,
   }
 
   // Otherwise, add the sequence key-value pair.
-  ignition::msgs::Header::Map *map = _msg->add_data();
+  gz::msgs::Header::Map *map = _msg->add_data();
   map->set_key("seq");
   map->add_value(value);
 }
