@@ -22,16 +22,16 @@
 #pragma warning(disable: 4005)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/camera_info.pb.h>
+#include <gz/msgs/camera_info.pb.h>
 #include <ignition/msgs.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
 
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Event.hh>
-#include <ignition/sensors/Manager.hh>
-#include <ignition/sensors/RgbdCameraSensor.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Event.hh>
+#include <gz/sensors/Manager.hh>
+#include <gz/sensors/RgbdCameraSensor.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering is disabling the
 // warnings
@@ -39,11 +39,11 @@
 #pragma warning(push)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/rendering/Material.hh>
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
-#include <ignition/rendering/Visual.hh>
+#include <gz/rendering/Material.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Visual.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
@@ -56,7 +56,7 @@
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
 
-using namespace ignition;
+using namespace gz;
 
 std::mutex g_mutex;
 unsigned int g_depthCounter = 0;
@@ -74,9 +74,9 @@ unsigned char *g_pointsRGBBuffer = nullptr;
 
 std::mutex g_infoMutex;
 unsigned int g_infoCounter = 0;
-ignition::msgs::CameraInfo g_infoMsg;
+msgs::CameraInfo g_infoMsg;
 
-void UnpackPointCloudMsg(const ignition::msgs::PointCloudPacked &_msg,
+void UnpackPointCloudMsg(const msgs::PointCloudPacked &_msg,
   float *_xyzBuffer, unsigned char *_rgbBuffer)
 {
   std::string msgBuffer = _msg.data();
@@ -115,7 +115,7 @@ void UnpackPointCloudMsg(const ignition::msgs::PointCloudPacked &_msg,
 }
 
 
-void OnCameraInfo(const ignition::msgs::CameraInfo & _msg)
+void OnCameraInfo(const msgs::CameraInfo & _msg)
 {
   g_infoMutex.lock();
   g_infoCounter++;
@@ -123,7 +123,7 @@ void OnCameraInfo(const ignition::msgs::CameraInfo & _msg)
   g_infoMutex.unlock();
 }
 
-void OnDepthImage(const ignition::msgs::Image &_msg)
+void OnDepthImage(const msgs::Image &_msg)
 {
   g_mutex.lock();
   unsigned int depthSamples = _msg.width() * _msg.height();
@@ -135,7 +135,7 @@ void OnDepthImage(const ignition::msgs::Image &_msg)
   g_mutex.unlock();
 }
 
-void OnImage(const ignition::msgs::Image &_msg)
+void OnImage(const msgs::Image &_msg)
 {
   g_imgMutex.lock();
   unsigned int imgSize = _msg.width() * _msg.height() * 3;
@@ -146,7 +146,7 @@ void OnImage(const ignition::msgs::Image &_msg)
   g_imgMutex.unlock();
 }
 
-void OnPointCloud(const ignition::msgs::PointCloudPacked &_msg)
+void OnPointCloud(const msgs::PointCloudPacked &_msg)
 {
   g_pcMutex.lock();
 
@@ -174,7 +174,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     const std::string &_renderEngine)
 {
   // get the darn test data
-  std::string path = ignition::common::joinPaths(PROJECT_SOURCE_PATH, "test",
+  std::string path = common::joinPaths(PROJECT_SOURCE_PATH, "test",
       "sdf", "rgbd_camera_sensor_builtin.sdf");
   sdf::SDFPtr doc(new sdf::SDF());
   sdf::init(doc);
@@ -199,7 +199,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   double near_ = clipPtr->Get<double>("near");
 
   double unitBoxSize = 1.0;
-  ignition::math::Vector3d boxPosition(3.0, 0.0, 0.0);
+  math::Vector3d boxPosition(3.0, 0.0, 0.0);
 
   // If ogre is not the engine, don't run the test
   if ((_renderEngine.compare("ogre") != 0) &&
@@ -211,7 +211,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = ignition::rendering::engine(_renderEngine);
+  auto *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -219,36 +219,37 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     return;
   }
 
-  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
+  rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // Create an scene with a box in it
   scene->SetAmbientLight(0.0, 0.0, 1.0);
-  ignition::rendering::VisualPtr root = scene->RootVisual();
+  rendering::VisualPtr root = scene->RootVisual();
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
 
   // create blue material
-  ignition::rendering::MaterialPtr blue = scene->CreateMaterial();
+  rendering::MaterialPtr blue = scene->CreateMaterial();
   blue->SetAmbient(0.0, 0.0, 1.0);
   blue->SetDiffuse(0.0, 0.0, 1.0);
   blue->SetSpecular(0.0, 0.0, 1.0);
 
   // create box visual
-  ignition::rendering::VisualPtr box = scene->CreateVisual();
+  rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
   box->SetLocalRotation(0, 0, 0);
   box->SetLocalScale(unitBoxSize, unitBoxSize, unitBoxSize);
   box->SetMaterial(blue);
+  scene->DestroyMaterial(blue);
   root->AddChild(box);
 
   // do the test
-  ignition::sensors::Manager mgr;
+  sensors::Manager mgr;
 
-  ignition::sensors::RgbdCameraSensor *rgbdSensor =
-      mgr.CreateSensor<ignition::sensors::RgbdCameraSensor>(sensorPtr);
+  sensors::RgbdCameraSensor *rgbdSensor =
+      mgr.CreateSensor<sensors::RgbdCameraSensor>(sensorPtr);
   ASSERT_NE(rgbdSensor, nullptr);
   EXPECT_FALSE(rgbdSensor->HasConnections());
   rgbdSensor->SetScene(scene);
@@ -258,21 +259,21 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
 
   std::string depthTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/depth_image";
-  WaitForMessageTestHelper<ignition::msgs::Image> depthHelper(depthTopic);
+  WaitForMessageTestHelper<msgs::Image> depthHelper(depthTopic);
   EXPECT_TRUE(rgbdSensor->HasConnections());
 
   std::string imageTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/image";
-  WaitForMessageTestHelper<ignition::msgs::Image> imageHelper(imageTopic);
+  WaitForMessageTestHelper<msgs::Image> imageHelper(imageTopic);
 
   std::string pointsTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/points";
-  WaitForMessageTestHelper<ignition::msgs::PointCloudPacked>
+  WaitForMessageTestHelper<msgs::PointCloudPacked>
       pointsHelper(pointsTopic);
 
   std::string infoTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/camera_info";
-  WaitForMessageTestHelper<ignition::msgs::CameraInfo> infoHelper(infoTopic);
+  WaitForMessageTestHelper<msgs::CameraInfo> infoHelper(infoTopic);
 
   // Update once to create image
   mgr.RunOnce(std::chrono::steady_clock::duration::zero());
@@ -282,7 +283,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   EXPECT_TRUE(pointsHelper.WaitForMessage()) << pointsHelper;
 
   // subscribe to the depth camera topic
-  ignition::transport::Node node;
+  transport::Node node;
   node.Subscribe(depthTopic, &OnDepthImage);
 
   // subscribe to the image topic
@@ -304,7 +305,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   int infoCounter = 0;
   int imgCounter = 0;
   int pcCounter = 0;
-  ignition::msgs::CameraInfo infoMsg;
+  msgs::CameraInfo infoMsg;
   for (int sleep = 0; sleep < 300 &&
       (counter == 0 || infoCounter == 0 || imgCounter == 0 || pcCounter == 0);
       ++sleep)
@@ -365,8 +366,8 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_NEAR(g_depthBuffer[mid], expectedRangeAtMidPoint, DEPTH_TOL);
 
     // The left and right side of the depth frame should be inf
-    EXPECT_DOUBLE_EQ(g_depthBuffer[left], ignition::math::INF_D);
-    EXPECT_DOUBLE_EQ(g_depthBuffer[right], ignition::math::INF_D);
+    EXPECT_DOUBLE_EQ(g_depthBuffer[left], math::INF_D);
+    EXPECT_DOUBLE_EQ(g_depthBuffer[right], math::INF_D);
   }
 
   // check color
@@ -377,7 +378,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
+    // See https://github.com/gazebosim/gz-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -408,16 +409,16 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     float lx = g_pointsXYZBuffer[imgLeft];
     float ly = g_pointsXYZBuffer[imgLeft + 1];
     float lz = g_pointsXYZBuffer[imgLeft + 2];
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, lx);
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, ly);
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, lz);
+    EXPECT_FLOAT_EQ(math::INF_D, lx);
+    EXPECT_FLOAT_EQ(math::INF_D, ly);
+    EXPECT_FLOAT_EQ(math::INF_D, lz);
 
     float rx = g_pointsXYZBuffer[imgRight];
     float ry = g_pointsXYZBuffer[imgRight + 1];
     float rz = g_pointsXYZBuffer[imgRight + 2];
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, rx);
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, ry);
-    EXPECT_FLOAT_EQ(ignition::math::INF_D, rz);
+    EXPECT_FLOAT_EQ(math::INF_D, rx);
+    EXPECT_FLOAT_EQ(math::INF_D, ry);
+    EXPECT_FLOAT_EQ(math::INF_D, rz);
 
     // point to the left of mid point should have larger y value than mid
     // point, which in turn should have large y value than point to the
@@ -443,7 +444,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
+    // See https://github.com/gazebosim/gz-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -467,7 +468,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   // result against actual point cloud data
   {
     // init the point cloud msg to be filled
-    ignition::msgs::PointCloudPacked pointsMsg;
+    msgs::PointCloudPacked pointsMsg;
     msgs::InitPointCloudPacked(pointsMsg, "depth2Image", true,
         {{"xyz", msgs::PointCloudPacked::Field::FLOAT32},
          {"rgb", msgs::PointCloudPacked::Field::FLOAT32}});
@@ -476,7 +477,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     pointsMsg.set_row_step(pointsMsg.point_step() * rgbdSensor->ImageWidth());
 
     // fill msg does the conversion from depth to points
-    ignition::sensors::PointCloudUtil pointsUtil;
+    sensors::PointCloudUtil pointsUtil;
     pointsUtil.FillMsg(pointsMsg, 1.05, g_pointsRGBBuffer, g_depthBuffer);
 
     // Unpack the point cloud msg into separate rgb and xyz buffers
@@ -529,11 +530,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
 
   // Check that for a box really close it returns -inf
-  root->RemoveChild(box);
-  ignition::math::Vector3d boxPositionNear(
+  math::Vector3d boxPositionNear(
       unitBoxSize * 0.5 + near_ * 0.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionNear);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0; sleep < 300 &&
@@ -581,7 +580,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
       for (unsigned int j = 0; j < rgbdSensor->ImageWidth(); ++j)
       {
         unsigned int index = step + j;
-        EXPECT_FLOAT_EQ(-ignition::math::INF_D, g_depthBuffer[index]);
+        EXPECT_FLOAT_EQ(-math::INF_D, g_depthBuffer[index]);
       }
     }
   }
@@ -615,9 +614,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
         float x = g_pointsXYZBuffer[index];
         float y = g_pointsXYZBuffer[index + 1];
         float z = g_pointsXYZBuffer[index + 2];
-        EXPECT_FLOAT_EQ(-ignition::math::INF_D, x);
-        EXPECT_FLOAT_EQ(-ignition::math::INF_D, y);
-        EXPECT_FLOAT_EQ(-ignition::math::INF_D, z);
+        EXPECT_FLOAT_EQ(-math::INF_D, x);
+        EXPECT_FLOAT_EQ(-math::INF_D, y);
+        EXPECT_FLOAT_EQ(-math::INF_D, z);
 
         unsigned int r = g_pointsRGBBuffer[index];
         unsigned int g = g_pointsRGBBuffer[index + 1];
@@ -635,11 +634,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_pcMutex.unlock();
 
   // Check that for a box really far it returns inf
-  root->RemoveChild(box);
-  ignition::math::Vector3d boxPositionFar(
+  math::Vector3d boxPositionFar(
       unitBoxSize * 0.5 + far_ * 1.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionFar);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0; sleep < 300 &&
@@ -687,7 +684,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
       for (unsigned int j = 0; j < rgbdSensor->ImageWidth(); ++j)
       {
         unsigned int index = step + j;
-        EXPECT_FLOAT_EQ(ignition::math::INF_D, g_depthBuffer[index]);
+        EXPECT_FLOAT_EQ(math::INF_D, g_depthBuffer[index]);
       }
     }
   }
@@ -721,9 +718,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
         float x = g_pointsXYZBuffer[index];
         float y = g_pointsXYZBuffer[index + 1];
         float z = g_pointsXYZBuffer[index + 2];
-        EXPECT_FLOAT_EQ(ignition::math::INF_D, x);
-        EXPECT_FLOAT_EQ(ignition::math::INF_D, y);
-        EXPECT_FLOAT_EQ(ignition::math::INF_D, z);
+        EXPECT_FLOAT_EQ(math::INF_D, x);
+        EXPECT_FLOAT_EQ(math::INF_D, y);
+        EXPECT_FLOAT_EQ(math::INF_D, z);
 
         unsigned int r = g_pointsRGBBuffer[index];
         unsigned int g = g_pointsRGBBuffer[index + 1];
@@ -740,9 +737,14 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
   g_pcMutex.unlock();
 
+  // Clean up rendering ptrs
+  box.reset();
+  blue.reset();
+
   // Clean up
+  mgr.Remove(rgbdSensor->Id());
   engine->DestroyScene(scene);
-  ignition::rendering::unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
@@ -752,12 +754,12 @@ TEST_P(RgbdCameraSensorTest, ImagesWithBuiltinSDF)
 }
 
 INSTANTIATE_TEST_CASE_P(RgbdCameraSensor, RgbdCameraSensorTest,
-    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
-  ignition::common::Console::SetVerbosity(4);
+  common::Console::SetVerbosity(4);
   ::testing::InitGoogleTest(&argc, argv);
   return RUN_ALL_TESTS();
 }
